<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>無効な半径</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>解決法がありません</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>エンティティまたは領域を選択</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>エンティティまたは参照を移動</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>第2角を設定</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>基準点としてターゲット点を指定</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>選択のターゲット点を指定</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>希望の位置にエンティティを移動</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>参照点の移動</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>選択範囲を移動</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>エンティティを移動</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>ブロック&apos;%1&apos;を編集中。&lt;br&gt;終了するには&lt;i&gt;ブロック&gt;メイン図面に戻る&lt;/i&gt;を選択して下さい</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>アクティブツール:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>なし</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">ブロックオプション</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>メインツール</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CADツール</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>エンティティはロックされた画層にあります。</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>長さ:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>エンティティはブロック参照ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>エンティティは線分または弧ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>エンティティは線分、弧またはポリラインではありません。 </translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>エンティティは線分ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>エンティティは弧または円ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>エンティティは線分、弧または円ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>エンティティは弧、円または楕円ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>エンティティは線分、弧、円または楕円ではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>エンティティは線分、弧、円、楕円またはポリラインではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>エンティティは線分,弧,円,楕円またはスプラインではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>エンティティは線分、弧、円、楕円、スプラインまたはポリラインではありません。</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>エンティティはポリラインではありません。</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">%1同心円の半径が0.0を下回りました。</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">%1同心弧の半径が0.0を下回りました。</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>少なくとも2点が同一です。</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>円が描画不可能です。</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>弧が描画不可能です。</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>無効なセグメントの数:%1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>無効な楕円 長軸/短軸: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>デフォルトを置き換え</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>シンボルを挿入</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>直径</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>円弧</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>プラス/マイナス</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>ほぼ同一</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>漸近的に同一</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>パイ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>平方根</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>ファイ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>ファイ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>アルト ファイ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>オーム</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>オメガ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>掛け算</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>割り算</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>四角</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>デルタ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>スタックされたテキスト</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>測定値</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>中央</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>揃える</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>中</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>フィット</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>上</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>ベース</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>下</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation type="unfinished">なし</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>アドオンの翻訳をロード中...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>アドオンをロード中...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>アドオンの初期化中...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>初期化中のアドオン:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">アドオンの初期化後処理...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>オブジェクト</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>オブジェクト</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>未知のオブジェクト</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>未知のオブジェクト</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>ブロック</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>レイヤー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>レイヤー</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>レイアウト</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>レイアウト</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>ラインタイプ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>ラインタイプ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>ビュー</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>表示</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>エンティティ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>３Dフェース</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>３Dフェース</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>ブロック参照</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>ブロック参照</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>ブロック参照と属性</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>ブロック参照と属性</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>弧</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>弧</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>属性</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>属性</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>属性の定義</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>属性定義</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>円</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>円</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>次元</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>位置合わせ寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>位置合わせ寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>角度寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>角度寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>直径寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>直径寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>縦座標寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>縦座標寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>回転（線形）寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>回転（線形）寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>半径寸法</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>半径寸法</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>楕円</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>楕円</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>ハッチング</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>画像</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>画像</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>引出線</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>引出線</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>線分</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>線分</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>無限の線</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>無限の線</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>光線</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>光線</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>点</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>点</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>ポリライン</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>ポリライン</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>ソリッド</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>ソリッド</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>トレース</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>トレース</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>フェイス</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>フェイス</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>スプライン</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>スプライン</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>テキストベース</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>テキスト</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>ビューポート</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>ビューポート</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>不明なエンティティ</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>不明なエンティティ</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>最初のエンティティはトリムできません。</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>エンティティはトリムできません。</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>２つ目のエンティティはトリムできません。</translation>
    </message>
</context>
</TS>
